@@ -1,8 +1,35 @@
-"""
-Borrowed from aioredi.
+"""Pool of connection using context manager protocol:
 
-:see: https://github.com/aio-libs/aioredis/blob/master/aioredis/pool.py
+.. code:: python
+
+
+    import asyncio
+    from aiogibson import create_pool
+
+    loop = asyncio.get_event_loop()
+
+    @asyncio.coroutine
+    def go():
+        pool = yield from create_pool('/tmp/aio.sock', minsize=5, maxsize=10,
+                                      loop=loop)
+
+        with (yield from pool) as gibson:
+            yield from gibson.set('foo', 'bar')
+            value = yield from gibson.get('foo')
+            print(value)
+
+        # or without context manager
+        yield from pool.set('foo', 'bar')
+        resp = yield from pool.get('foo')
+        yield from pool.delete('foo')
+
+        pool.clear()
+
+    loop.run_until_complete(go())
 """
+# reference implementation:
+# https://github.com/aio-libs/aioredis/blob/master/aioredis/pool.py
+
 
 import asyncio
 
@@ -103,7 +130,8 @@ class GibsonPool:
         return conn
 
     def release(self, conn):
-        """Returns used connection back into pool.
+        """Returns connection back into pool. Since this method is used
+         in ``__exit__()``, this method must not be coroutine.
         """
         assert conn in self._used, "Invalid connection, maybe from other pool"
         self._used.remove(conn)
@@ -140,6 +168,16 @@ class GibsonPool:
         conn = yield from self.acquire()
         return _ConnectionContextManager(self, conn)
 
+    def __getattr__(self, method):
+        # we have nice AttributeError here in case *method* is not found in
+        # Gibson class (high level interface)
+        @asyncio.coroutine
+        def caller(*args, **kw):
+            with (yield from self) as gibson:
+                resp = yield from getattr(gibson, method)(*args, **kw)
+            return resp
+        return caller
+
 
 class _ConnectionContextManager:
 
